OC.L10N.register(
    "settings",
    {
    "Private" : "Privé",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Visible uniquement pour les utilisateurs correspondants via l'intégration du numéro de téléphone dans Talk pour mobile",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Visible uniquement par les personnes dans cette instance et par les invités",
    "Federated" : "Fédéré",
    "Only synchronize to trusted servers" : "Synchronisation avec les serveurs de confiance uniquement",
    "Published" : "Publié",
    "Synchronize to trusted servers and the global and public address book" : "Synchronisation avec les serveurs de confiance et le carnet d'adresses mondial et public",
    "Verify" : "Vérifier",
    "Verifying …" : "Vérification en cours...",
    "Unable to change password" : "Impossible de modifier le mot de passe",
    "Very weak password" : "Mot de passe très faible",
    "Weak password" : "Mot de passe faible",
    "So-so password" : "Mot de passe tout juste acceptable",
    "Good password" : "Mot de passe satisfaisant",
    "Strong password" : "Mot de passe fort",
    "Groups" : "Groupes",
    "Group list is empty" : "La liste des groupes est vide",
    "Unable to retrieve the group list" : "Impossible de récupérer la liste des groupes",
    "{actor} added you to group {group}" : "{actor} vous a ajouté au groupe {group}",
    "You added {user} to group {group}" : "Vous avez ajouté {user} au groupe {group}",
    "{actor} added {user} to group {group}" : "{actor} a ajouté {user} au groupe {group}",
    "An administrator added you to group {group}" : "Un administrateur vous a ajouté au groupe {group}",
    "An administrator added {user} to group {group}" : "Un administrateur a ajouté {user} au groupe {group}",
    "{actor} removed you from group {group}" : "{actor} vous a retiré du groupe {group}",
    "You removed {user} from group {group}" : "Vous avez retiré {user} du groupe {group}",
    "{actor} removed {user} from group {group}" : "{actor} a retiré {user} du groupe {group}",
    "An administrator removed you from group {group}" : "Un administrateur vous a retiré du groupe {group}",
    "An administrator removed {user} from group {group}" : "Un administrateur a retiré {user} du groupe {group}",
    "Your <strong>group memberships</strong> were modified" : "Vos <strong>adhésions aux groupes</strong> ont été modifiées",
    "{actor} changed your password" : "{actor} a modifié votre mot de passe",
    "You changed your password" : "Vous avez modifié votre mot de passe",
    "Your password was reset by an administrator" : "Votre mot de passe a été réinitialisé par un administrateur",
    "Your password was reset" : "Votre mot de passe a été réinitialisé",
    "{actor} changed your email address" : "{actor} a modifié votre adresse e-mail",
    "You changed your email address" : "Vous avez modifié votre adresse e-mail",
    "Your email address was changed by an administrator" : "Votre adresse e-mail a été modifiée par un administrateur",
    "You created an app password for a session named \"{token}\"" : "Vous avez créé un mot de passe d'application pour une session nommée \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Un administrateur a créé un mot de passe d'application pour une session nommée \"{token}\"",
    "You deleted app password \"{token}\"" : "Vous avez supprimé un mot de passe d'application \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Vous avez renommé le mot de passe d'application \"{token}\" en \"{newToken}\" ",
    "You granted filesystem access to app password \"{token}\"" : "Vous avez accordé au système de fichiers l'accès au mot de passe d'application \"{token}\".",
    "You revoked filesystem access from app password \"{token}\"" : "Vous avez révoqué l'accès au système de fichiers à partir du mot de passe d'application \"{token}\".",
    "Security" : "Sécurité",
    "You successfully logged in using two-factor authentication (%1$s)" : "Vous avez réussi à vous connecter en utilisant l'authentification à deux facteurs (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Une tentative de connexion utilisant l'authentification à deux facteurs a échoué (%1$s)",
    "Remote wipe was started on %1$s" : "Effacement distant démarré pour%1$s",
    "Remote wipe has finished on %1$s" : "Effacement distant terminé pour %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Votre <strong>mot de passe</strong> ou <strong>adresse e-mail</strong> a été modifié⋅e",
    "Apps" : "Apps",
    "Could not remove app." : "Impossible de supprimer l'app.",
    "Could not update app." : "Impossible de mettre à jour l'app.",
    "Wrong password" : "Mot de passe incorrect",
    "Unable to change personal password" : "Impossible de changer le mot de passe personnel",
    "Saved" : "Sauvegardé",
    "No user supplied" : "Aucun utilisateur fourni",
    "Unable to change password. Password too long." : "Impossible de modifier le mot de passe. Le mot de passe est trop long.",
    "Authentication error" : "Erreur d'authentification",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données utilisateur seront perdues.",
    "Wrong admin recovery password. Please check the password and try again." : "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
    "Backend does not support password change, but the user's encryption key was updated." : "Le serveur ne permet pas le changement de mot de passe mais la clé de chiffrement a été modifiée.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installation et mises à jour d'applications via le magasin d'applications ou le partage fédéré",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilise %1$s version (%2$s), qui est une version obsolète. Veuillez mettre à jour votre système d'exploitation, ou des fonctionnalités telles que %3$s ne fonctionneront pas correctement.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Impossible de déterminer si la version TLS de cURL est dépassée ou non en raison d’une erreur survenue lors de la requête HTTPS vers https://nextcloud.com. Veuillez consulter le fichier journal de Nextcloud pour plus de détails.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Le module PHP 'OPcache' n'est pas chargé. Pour de meilleures performances, il est recommandé de le charger dans votre installation PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache est désactivé. Pour de meilleures performances, il est recommandé de définir <code>opcache.enable=1</code> dans votre fichier configuration PHP.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache est configuré pour retirer les commentaires du code. Avec OPcache activé, <code>opcache.save_comments=1</code> doit être ajouté au fichier de configuration PHP pour que Nextcloud fonctionne.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud n'est pas autorisé à utiliser l'API de OPcache. Avec OPcache activé, il est fortement recommandé d'inclure tous les répertoires de Nextcloud dans la variable <code>opcache.restrict_api</code> du fichier de configuration PHP ou de désactiver ces restrictions de l'API OPcache, pour éviter les erreurs pendant les mises à jour de Nextcloud ou des applications.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud n'est pas autorisé à utiliser l'API de OPcache. Il est fortement recommandé d'inclure tous les répertoires de Nextcloud dans la variable 1opcache.restrict_api1 du fichier de configuration PHP ou de désactiver ces restrictions de l'API OPcache, pour éviter les erreurs pendant les mises à jour de Nextcloud ou des applications.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "L'OPcache basé sur la mémoire partagée est désactivé. Pour de meilleures performances, il est recommandé de paramétrer<code>opcache.file_cache_only=0</code> dans votre configuration PHP et d'utiliser le cache fichier comme cache de second niveau seulement.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Le nombre maximum de clés OPcache est presque dépassé. Pour vous assurer que tous les scripts puissent être conservés en cache, il est recommandé de définir la variable <code>opcache.max_accelerated_files</code> de votre fichier de configuration PHP à une valeur supérieure à <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Le tampon mémoire OPcache est presque plein. Pour vous assurer que tous les scripts peuvent être conservés en cache, il est recommandé de définir la variable  <code>opcache.memory_consumption</code> de votre fichier de configuration PHP à une valeur supérieure à <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Le tampon mémoire des chaînes internes OPcache est presque plein. Pour vous assurer que les chaînes répétitives peuvent être mise en cache, il est recommandé de définir la variable <code>opcache.interned_strings_buffer</code> de votre fichier de configuration PHP à une valeur supérieure à <code>%s</code>.",
    "Administrator documentation" : "Documentation administrateur",
    "User documentation" : "Documentation utilisateur",
    "Invalid SMTP password." : "Mot de passe SMTP incorrect.",
    "Email setting test" : "Test des paramètres de messagerie",
    "Well done, %s!" : "Bien joué, %s !",
    "If you received this email, the email configuration seems to be correct." : "Si vous avez reçu cet e-mail, la configuration de l'adresse e-mail semble être correcte.",
    "Email could not be sent. Check your mail server log" : "L'e-mail n'a pu être envoyé. Vérifiez le journal du serveur de messagerie",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Vous devez définir votre e-mail utilisateur avant de tester l'envoi d'e-mail. Aller à %s pour cela.",
    "Users" : "Utilisateurs",
    "Invalid user" : "Utilisateur non valide",
    "Invalid mail address" : "Adresse e-mail non valide",
    "Settings saved" : "Paramètres sauvegardés",
    "Unable to change full name" : "Impossible de modifier le nom complet",
    "Unable to change email address" : "Impossible de modifier l'adresse e-mail",
    "Unable to set invalid phone number" : "Impossible d'enregistrer un n° de téléphone incorrect",
    "Unable to set invalid website" : "Impossible d'enregistrer un site web incorrect",
    "Some account data was invalid" : "Certaines données du compte ne sont pas valides",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pour vérifier votre compte Twitter, postez le tweet suivant sur Twitter (veuillez vérifier de le poster sans saut de ligne) :",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pour vérifier votre site web, placez le contenu suivant à la racine de votre site à '.well-known/CloudIdVerificationCode.txt' (veuillez vérifier que le texte complet est en une seule ligne) :",
    "%1$s changed your password on %2$s." : "%1$s a modifié votre mot de passe sur %2$s.",
    "Your password on %s was changed." : "Votre mot de passe sur %s a été modifié.",
    "Your password on %s was reset by an administrator." : "Votre mot de passe sur %s a été réinitialisé par un administrateur.",
    "Your password on %s was reset." : "Votre mot de passe sur %s a été réinitialisé.",
    "Password for %1$s changed on %2$s" : "Le mot de passe pour %1$s a été modifié sur %2$s",
    "Password changed for %s" : "Mot de passe modifié pour %s",
    "If you did not request this, please contact an administrator." : "Si vous n'avez pas effectué cette demande, veuillez contacter un administrateur.",
    "Your email address on %s was changed." : "Votre adresse e-mail sur %s a été modifiée.",
    "Your email address on %s was changed by an administrator." : "Votre adresse e-mail sur %s a été modifiée par un administrateur.",
    "Email address for %1$s changed on %2$s" : "L'adresse e-mail pour %1$s a été modifiée sur %2$s",
    "Email address changed for %s" : "L'adresse e-mail a été modifiée pour %s",
    "The new email address is %s" : "La nouvelle adresse e-mail est %s",
    "Your %s account was created" : "Votre compte %s a été créé",
    "Welcome aboard" : "Bienvenue à bord",
    "Welcome aboard %s" : "Bienvenue à bord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenue dans votre compte %s, vous pouvez ajouter, protéger et partager vos données.",
    "Your username is: %s" : "Votre nom d'utilisateur est : %s",
    "Set your password" : "Créer votre mot de passe",
    "Go to %s" : "Aller à %s",
    "Install Client" : "Installer le Client",
    "Logged in user must be a subadmin" : "L'utilisateur connecté doit être un sous-administrateur",
    "Settings" : "Paramètres",
    "Personal" : "Personnel",
    "Administration" : "Administration",
    "Additional settings" : "Paramètres supplémentaires",
    "Administration privileges" : "Privilèges d'administration",
    "Groupware" : "Groupware",
    "Overview" : "Vue d'ensemble",
    "Basic settings" : "Paramètres de base",
    "Sharing" : "Partage",
    "Availability" : "Disponibilité",
    "Calendar" : "Agenda",
    "Personal info" : "Informations personnelles",
    "Mobile & desktop" : "Mobile & bureau",
    "Email server" : "Serveur de messagerie",
    "Security & setup warnings" : "Avertissements de sécurité & configuration",
    "Background jobs" : "Tâches de fond",
    "Create" : "Créer",
    "Change" : "Modifier",
    "Delete" : "Supprimer",
    "Reshare" : "Repartager",
    "Unlimited" : "Illimité",
    "Verifying" : "Vérification en cours",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Une tâche en arrière-plan qui vérifie les certificats SSL importés par l’utilisateur est en attente. Veuillez vérifier plus tard.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Certains certificats SSL importés par les utilisateurs sont présents et ne sont plus utilisés avec Nextcloud 21. Ils peuvent être importés par l'interface en ligne de commande via la commande \"occ security:certificates:import\". Leurs chemins dans le dossier data sont affichés ci-dessous.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Des UUID invalides pour les utilisateurs LDAP ont été trouvés. Merci de vérifier votre paramètre \"Passer outre la détection des UUID\" dans la partie Expert de la configuration LDAP puis utiliser \"occ ldap:update-uuid\" pour les mettre à jour.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "L'ancien format de chiffrement côté serveur est activé. Nous recommandons de le désactiver.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" est utilisé. Nextcloud 21 et plus ne sont plus compatibles avec cette version et nécessitent MariaDB 10.2 ou plus.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" est utilisé. Nextcloud 21 et plus ne sont plus compatibles avec cette version et nécessitent MySQL 8.0 or MariaDB 10.2 ou plus.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL version \"%s\" est utilisé. Nextcloud 21 et plus ne sont plus compatibles avec cette version et nécessitent PostgreSQL 9.6 ou plus.",
    "Profile information" : "Information du profil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Photo de profil, nom complet, adresse e-mail, numéro de téléphone, adresse, site web, Twitter, organisation, fonction, titre, à propos, et si votre profil est activé",
    "Nextcloud settings" : "Paramètres Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Ici, vous pouvez décider quel groupe peut accéder à certaines sections des paramètres d'administration.",
    "None" : "Aucun",
    "Unable to modify setting" : "Impossible de modifier le paramètre",
    "Two-Factor Authentication" : "Authentification à deux facteurs",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "L'authentification à deux facteurs peut être forcée pour tous les utilisateurs et des groupes spécifiques. S'ils n'ont pas un fournisseur à deux facteurs configuré, ils ne seront pas capables de s'authentifier sur le système.",
    "Enforce two-factor authentication" : "Imposer l'authentification à deux facteurs",
    "Limit to groups" : "Limiter aux groupes",
    "Enforcement of two-factor authentication can be set for certain groups only." : "L'authentification à deux facteurs peut être imposée à certains groupes seulement.",
    "Two-factor authentication is enforced for all members of the following groups." : "L'authentification à deux facteurs est forcée pour tous les membres des groupes suivants : ",
    "Enforced groups" : "Groupes forcés",
    "Two-factor authentication is not enforced for members of the following groups." : "L'authentification à deux facteurs n'est pas forcée pour les membres des groupes suivants : ",
    "Excluded groups" : "Groupes exclus",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Lorsque des groupes sont forcés/exclus, la logique suivante est utilisée pour déterminer si l'authentification à double facteur (A2F) est imposée à un utilisateur. Si aucun groupe n'est forcé, l'authentification à double facteur est activée pour tous sauf pour les membres des groupes exclus. Si des groupes sont forcés, l'authentification à double facteur est exigée pour tous les membres de ces groupes. Si un utilisateur est à la fois dans un groupe forcé et exclu, c'est le groupe forcé qui prime et l'authentification double facteur est imposée.",
    "Save changes" : "Enregistrer les modifications",
    "All" : "Tous",
    "Limit app usage to groups" : "Limiter l'utilisation de l'application aux groupes",
    "No results" : "Aucun résultat",
    "Update to {version}" : "Mettre à jour vers {version}",
    "Remove" : "Supprimer",
    "Disable" : "Désactiver",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Cette application n'a pas de version minimum Nextcloud exigée. Ce sera considéré comme une erreur à l'avenir.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Cette application n'a pas de version maximum Nextcloud exigée. Ce sera considéré comme une erreur à l'avenir.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
    "View in store" : "Afficher dans le magasin d'applications",
    "Visit website" : "Visiter le site web",
    "Report a bug" : "Signaler un bogue",
    "Admin documentation" : "Documentation administrateur",
    "Developer documentation" : "Documentation pour développeurs",
    "This app is supported via your current Nextcloud subscription." : "Cette application bénéficie d'un support grâce à votre abonnement Nextcloud.",
    "Supported" : "Pris en charge",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les applications mises en avant sont développées par la communauté. Elles proposent des fonctionnalités centrales et sont prêtes pour la production.",
    "Featured" : "Mise en avant",
    "Update to {update}" : "Mettre à jour vers {update}",
    "All apps are up-to-date." : "Toutes les applications sont à jour.",
    "Results from other categories" : "Résultats d'autres catégories",
    "No apps found for your version" : "Pas d'application trouvée pour votre version",
    "Disable all" : "Tout désactiver",
    "Enable all" : "Tout activer",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n application a une mise à jour disponible","%n applications ont une mise à jour disponible","%n applications ont une mise à jour disponible"],
    "_Update_::_Update all_" : ["Mettre à jour","Tout mettre à jour","Tout mettre à jour"],
    "Marked for remote wipe" : "Marqué pour l'effaçage distant",
    "Device settings" : "Paramètres de l'appareil",
    "Allow filesystem access" : "Autoriser l'accès au gestionnaire de fichiers",
    "Rename" : "Renommer",
    "Revoke" : "Révoquer",
    "Wipe device" : "Effacer l'appareil",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Révoquer ce jeton peut empêcher l'effacement de votre appareil s'il n'a pas encore démarré l'effacement.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome pour Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "Application iOS {productName}",
    "{productName} Android app" : "Application Android {productName}",
    "{productName} Talk for iOS" : " {productName} Talk pour iOS",
    "{productName} Talk for Android" : " {productName} Talk pour Android",
    "Sync client - {os}" : "Client de synchronisation - {os}",
    "This session" : "Cette session",
    "Device" : "Appareil",
    "Last activity" : "Dernière activité",
    "Devices & sessions" : "Appareils & sessions",
    "Web, desktop and mobile clients currently logged in to your account." : "Clients web, applications de bureau et mobiles actuellement connectés avec votre compte.",
    "Do you really want to wipe your data from this device?" : "Voulez-vous vraiment supprimer vos données de cet appareil ?",
    "Confirm wipe" : "Confirmer la suppression",
    "Error while creating device token" : "Erreur lors de la création du jeton de l'appareil",
    "Error while updating device token scope" : "Erreur lors de la mise à jour de la visibilité du jeton de l'appareil",
    "Error while updating device token name" : "Erreur lors de la mise à jour du nom du jeton",
    "Error while deleting the token" : "Erreur lors de la suppression du jeton",
    "Error while wiping the device with the token" : "Erreur lors de l'effacement de l'appareil avec le jeton",
    "App name" : "Nom de l'application",
    "Create new app password" : "Créer un nouveau mot de passe d'application",
    "Use the credentials below to configure your app or device." : "Utilisez les informations d'identification ci-dessous pour configurer votre application ou appareil.",
    "For security reasons this password will only be shown once." : "Pour des raisons de sécurité, ce mot de passe ne sera affiché qu'une seule fois.",
    "Username" : "Nom d'utilisateur",
    "Password" : "Mot de passe",
    "Done" : "Terminé",
    "Show QR code for mobile apps" : "Afficher le QR code pour les applications mobiles",
    "Copied!" : "Copié !",
    "Copy" : "Copier",
    "Could not copy app password. Please copy it manually." : "Impossible de copier le mot de passe de l'application. Merci de le copier manuellement.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Pour que le serveur fonctionne correctement, il est important de configurer correctement les tâches d'arrière-plan. Cron est le paramètre recommandé. Veuillez consulter la documentation pour plus d'informations.",
    "Last job execution ran {time}. Something seems wrong." : "La dernière exécution de la tâche a duré {time}. Quelque chose semble dysfonctionner.",
    "Last job ran {relativeTime}." : "Dernière tâche exécutée {relativeTime}.",
    "Background job did not run yet!" : "La tâche de fond n'a pas encore été exécutée !",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Exécuter une tâche à chaque chargement de page. Cas d'utilisation : Instance avec un seul utilisateur.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php est enregistré dans un service webcron pour appeler cron.php toutes les 5 minutes via HTTP. Cas d'utilisation : Très petite instance (1-5 utilisateurs selon l'utilisation).",
    "Cron (Recommended)" : "Cron (Recommandé)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Pour l'exécuter, vous devez avoir l'extension PHP POSIX. Regarder la {linkstart}documentation PHP{linkend} pour plus de détails.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Utiliser le service cron du système pour appeler le fichier 'cron.php' toutes les 5 minutes.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Le script cron.php doit être exécuté par l'utilisateur système \"{user}\".",
    "Unable to update background job mode" : "Impossible de mettre à jour le mode d'exécution des tâches de fond",
    "Profile" : "Profil",
    "Enable or disable profile by default for new users." : "Activer ou désactiver le profil par défaut pour les nouveaux utilisateurs.",
    "Enable" : "Activer",
    "Unable to update profile default setting" : "Impossible de mettre à jour les paramètres par défaut du profil",
    "Server-side encryption" : "Chiffrement côté serveur",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Le chiffrement côté serveur permet de chiffrer les fichiers qui sont téléversés sur ce serveur. Cela implique des limitations comme une performance moindre, donc activez-le seulement si nécessaire.",
    "Enable server-side encryption" : "Activer le chiffrement côté serveur",
    "Please read carefully before activating server-side encryption:" : "Veuillez lire attentivement avant d’activer le chiffrement côté serveur :",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Une fois le chiffrement activé, les fichiers téléversés sur le serveur à partir de ce moment seront stockés sous forme chiffrée. Il n'est possible de désactiver le chiffrement que si le module utilisé le permet spécifiquement, et que toutes les conditions préalables sont réunies pour ce faire (par exemple la création d'une clef de récupération).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Le chiffrement seul ne garantit pas la sécurité du système. Veuillez consulter la documentation pour plus d'informations à propos du fonctionnement de l'application de chiffrement, et des cas d'usage supportés.",
    "Be aware that encryption always increases the file size." : "Veuillez noter que le chiffrement augmente toujours la taille des fichiers.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Il est opportun de sauvegarder régulièrement vos données. Si ces données sont chiffrées, n'oubliez pas de sauvegarder aussi les clés de chiffrement.",
    "This is the final warning: Do you really want to enable encryption?" : "Dernier avertissement : Voulez-vous vraiment activer le chiffrement ?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Aucun module de chiffrement n'est chargé. Merci d'activer un module de chiffrement dans le menu des applications.",
    "Select default encryption module:" : "Sélectionnez le module de chiffrement par défaut :",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Vous devez migrer vos clés de chiffrement de l'ancienne version de chiffrement (ownCloud <= 8.0) vers la nouvelle. Veuillez activer l'application \\\"Default Encryption Module\\\" et exécuter {command}",
    "Unable to update server side encryption config" : "Impossible de mettre à jour la configuration du chiffrement côté serveur",
    "Rename group" : "Renommer le groupe",
    "Remove group" : "Supprimer le groupe",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Vous êtes sur le point de supprimer le groupe {group}. Les utilisateurs ne seront PAS supprimés.",
    "Please confirm the group removal " : "Veuillez confirmer la suppression du groupe",
    "Current password" : "Mot de passe actuel",
    "New password" : "Nouveau mot de passe",
    "Change password" : "Changer de mot de passe",
    "Your profile information" : "Informations de votre profil",
    "Your profile picture" : "Votre photo de profil",
    "Upload profile picture" : "Téléverser une photo de profil",
    "Choose profile picture from Files" : "Choisir une image de profil dans Fichiers",
    "Remove profile picture" : "Retirer la photo de profil",
    "The file must be a PNG or JPG" : "Le fichier doit être au format PNG ou JPG",
    "Picture provided by original account" : "Photo fournie par le compte original",
    "Cancel" : "Annuler",
    "Set as profile picture" : "Définir comme image de profil",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Veuillez noter que cela peut prendre jusqu'à 24 heures pour que votre image de profil soit mise à jour partout.",
    "Choose your profile picture" : "Choisir votre image de profil",
    "Please select a valid png or jpg file" : "Merci de sélectionner un fichier jpg ou png valide",
    "Error setting profile picture" : "Erreur lors de la redéfinition de l'image de profil",
    "Error cropping profile picture" : "Erreur lors du recadrage d'image de profil",
    "Error saving profile picture" : "Erreur lors de la sauvegarde de l'image de profil",
    "Error removing profile picture" : "Erreur lors de la suppression de l'image de profil",
    "Your biography" : "Votre biographie",
    "Details" : "Détails",
    "You are a member of the following groups:" : "Vous êtes membre des groupes suivants :",
    "You are using <strong>{usage}</strong>" : "Vous utilisez <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Vous utilisez <strong>{usage}</strong> sur <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Votre nom complet",
    "Email options" : "Options de messagerie",
    "Primary email for password reset and notifications" : "Adresse e-mail principale pour la réinitialisation du mot de passe et les notifications",
    "Remove primary email" : "Supprimer l'adresse e-mail principale",
    "Delete email" : "Supprimer l'adresse e-mail",
    "Unset as primary email" : "Ne plus définir comme adresse e-mail principale",
    "This address is not confirmed" : "Cette adresse n'est pas confirmée",
    "Set as primary email" : "Définir comme adresse e-mail principale",
    "Your email address" : "Votre adresse e-mail",
    "Additional email address {index}" : "E-mail supplémentaire {index}",
    "Unable to delete primary email address" : "Impossible de supprimer l'adresse e-mail principale",
    "Unable to update primary email address" : "Impossible de modifier l'adresse e-mail principale",
    "Unable to add additional email address" : "Impossible d'ajouter une adresse e-mail supplémentaire",
    "Unable to update additional email address" : "Impossible de modifier l'adresse e-mail supplémentaire",
    "Unable to delete additional email address" : "Impossible de supprimer l'adresse e-mail supplémentaire",
    "No email address set" : "Aucune adresse e-mail configurée",
    "Additional emails" : "E-mails suplémentaires",
    "Your handle" : "Votre identifiant",
    "Your headline" : "Votre titre",
    "Language" : "Langue",
    "Help translate" : "Aidez à traduire",
    "Unable to update language" : "Impossible de modifier la langue",
    "No language set" : "Aucune langue définie",
    "Locale" : "Paramètres régionaux",
    "Week starts on {firstDayOfWeek}" : "Les semaines commencent le {firstDayOfWeek}",
    "Unable to update locale" : "Impossible de mettre à jour les paramètres régionaux",
    "No locale set" : "Paramètres régionaux non définis",
    "Your location" : "Votre localisation",
    "Your organisation" : "Votre organisation",
    "Your phone number" : "Votre numéro de téléphone",
    "Edit your Profile visibility" : "Visibilité du profil",
    "Enable Profile" : "Activer le profil",
    "Unable to update profile enabled state" : "Impossible de mettre à jour l'état du profil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Le paramètre le plus restrictif entre la visibilité et la confidentialité est respecté. Par exemple, si la visibilité est définie à \"Montrer à tout le monde\" et que la confidentialité est \"Privée\", \"Privée\" est respecté.",
    "Unable to update visibility of {displayId}" : "Impossible de mettre à jour la visibilité de {displayId}",
    "Your role" : "Votre fonction",
    "Your Twitter handle" : "Votre pseudo Twitter",
    "Your website" : "Votre site web",
    "No {property} set" : "{property} n'est pas défini",
    "Unable to update {property}" : "Impossible de mettre à jour {property}",
    "Change scope level of {property}, current scope is {scope}" : "Changer la portée de {property}, la portée actuelle est {scope}",
    "Unable to update federation scope of the primary {property}" : "Impossible de mettre à jour la portée de la fédération pour le/la {property} principal(e)",
    "Unable to update federation scope of additional {property}" : "Impossible de mettre à jour la portée de la fédération pour le/la {property} additionnel(le)",
    "Add additional email" : "Ajouter un e-mail supplémentaire",
    "Add" : "Ajouter",
    "You do not have permissions to see the details of this user" : "Vous n'avez pas les autorisations pour voir le détail de cet utilisateur",
    "Add new password" : "Ajouter un nouveau mot de passe",
    "Add new email address" : "Ajouter une nouvelle adresse e-mail",
    "Add user to group" : "Ajouter l'utilisateur au groupe",
    "Set user as admin for" : "Définir en tant qu'administrateur pour",
    "Select user quota" : "Sélectionner le quota de l'utilisateur ",
    "Delete user" : "Supprimer l'utilisateur",
    "Wipe all devices" : "Effacer tous les appareils",
    "Disable user" : "Désactiver l'utilisateur",
    "Enable user" : "Activer l'utilisateur",
    "Resend welcome email" : "Renvoyer l'e-mail de bienvenue",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En cas de perte d'appareil ou si vous quittez un groupe ou une organisation, cela pourra supprimer les données de tous les appareils associés à {userid}. Ne fonctionne que si les appareils associés sont connectés à internet.",
    "Remote wipe of devices" : "Effacer les appareils à distance",
    "Wipe {userid}'s devices" : "Effacer les appareils de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Supprime totalement le compte de {userid} et toutes ses données associées (fichiers personnels, données des applications, etc.)",
    "Account deletion" : "Suppression de compte",
    "Delete {userid}'s account" : "Supprimer le compte {userid}",
    "Welcome mail sent!" : "E-mail de bienvenue envoyé !",
    "Edit User" : "Modifier l'utilisateur",
    "Toggle user actions menu" : "Afficher / Masquer le menu des actions de l'utilisateur",
    "{size} used" : "{size} utilisés",
    "New user" : "Nouvel utilisateur",
    "Will be autogenerated" : "Sera généré automatiquement",
    "Display name" : "Nom d'affichage",
    "Email" : "E-mail",
    "Default language" : "Langue par défaut",
    "Add a new user" : "Ajouter un nouvel utilisateur",
    "Group admin for" : "Administrateur de groupe pour",
    "Quota" : "Quota",
    "User backend" : "Origine du compte",
    "Storage location" : "Emplacement du stockage",
    "Last login" : "Dernière connexion",
    "No users in here" : "Aucun utilisateur",
    "Default quota" : "Quota par défaut",
    "Common languages" : "Langues communes",
    "Other languages" : "Autres langues",
    "Password change is disabled because the master key is disabled" : "Le changement de mot de passe est désactivé car la clé principale est désactivée",
    "Passwordless authentication requires a secure connection." : "L'authentification sans mot de passe requiert une connexion sécurisée.",
    "Add WebAuthn device" : "Ajouter un appareil WebAuthn",
    "Please authorize your WebAuthn device." : "Veuillez autoriser votre appareil WebAuthn.",
    "Name your device" : "Nommez votre appareil",
    "Adding your device …" : "Ajout de votre appareil…",
    "Server error while trying to add WebAuthn device" : "Erreur du serveur lors de l'ajout du périphérique WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Erreur du serveur lors de l'enregistrement de l'appareil WebAuthn",
    "Unnamed device" : "Appareil sans nom",
    "Passwordless Authentication" : "Authentification sans mot de passe",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configurer votre compte pour une authentification sans mot de passe suivant le standard FIDO2.",
    "No devices configured." : "Aucun périphérique paramétré.",
    "The following devices are configured for your account:" : "Les appareils suivants sont paramétrés pour votre compte :",
    "Your browser does not support WebAuthn." : "Votre navigateur ne prend pas en charge WebAuthn.",
    "Your apps" : "Vos applications",
    "{license}-licensed" : "Sous licence {license}",
    "Changelog" : "Journal des modifications",
    "by {author}\n{license}" : "par {author}\n{license}",
    "Enter group name" : "Saisissez le nom du groupe",
    "Add group" : "Ajouter un groupe",
    "Active users" : "Utilisateurs actifs",
    "Admins" : "Administrateurs",
    "Disabled users" : "Utilisateurs désactivés",
    "Default quota:" : "Quota par défaut :",
    "Select default quota" : "Sélectionner le quota par défaut",
    "Show Languages" : "Afficher la langue",
    "Show last login" : "Afficher la dernière connexion",
    "Show user backend" : "Afficher l'origine du compte",
    "Show storage path" : "Afficher l'emplacement du stockage",
    "Send email to new user" : "Envoyer un e-mail aux nouveaux utilisateurs",
    "Not saved" : "Non sauvegardé",
    "Sending…" : "Envoi en cours...",
    "Email sent" : "E-mail envoyé",
    "Location" : "Emplacement",
    "Profile picture" : "Image de profil",
    "About" : "À propos",
    "Full name" : "Nom complet",
    "Additional email" : "Adresse e-mail supplémentaire",
    "Headline" : "Titre",
    "Organisation" : "Organisation",
    "Phone number" : "Numéro de téléphone",
    "Role" : "Fonction",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "Fediverse (ex. Mastodon)",
    "Website" : "Site web",
    "Profile visibility" : "Visibilité du profil",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Non disponible car cette propriété est requise pour les fonctionnalités essentielles comme le partage de fichiers et les invitations de l'agenda.",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Non disponible car la fédération a été désactivée pour votre compte, contactez votre administrateur système si vous avez des questions.",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Non disponible car la publication de données spécifiques d'un utilisateur au serveur de recherche est interdit, contacter votre administrateur système si vous avez des questions",
    "Active apps" : "Applications actives",
    "Disabled apps" : "Applications désactivées",
    "Updates" : "Mises à jour",
    "App bundles" : "Packs d'applications",
    "Featured apps" : "Applications mises en avant",
    "Show to everyone" : "Montrer à tout le monde",
    "Show to logged in users only" : "Montrer seulement aux utilisateurs connectés",
    "Hide" : "Cacher",
    "Download and enable" : "Télécharger et activer",
    "Enable untested app" : "Activer l'application non testée",
    "The app will be downloaded from the App Store" : "L'application sera téléchargée depuis le magasin d'applications",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Cette application n'est pas indiquée comme étant compatible avec votre version de Nextcloud. Si vous continuez vous pourrez toujours installer l'app. Notez cependant qu'elle pourrait ne pas fonctionner comme prévu.",
    "Never" : "Jamais",
    "An error occurred during the request. Unable to proceed." : "Une erreur s'est produite pendant la demande. Impossible de poursuivre.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Erreur : cette application ne peut être activée car elle rend le serveur instable",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Il y a trop de requêtes depuis votre réseau. Réessayez plus tard ou contactez votre administrateur s'il s'agit d'une erreur.",
    "Documentation" : "Documentation",
    "Forum" : "Forum",
    "Login" : "Login",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "Ouvrir la documentation",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Il est important d'indiquer un serveur afin de pouvoir envoyer des mails en cas de perte de mot de passe et pour d'autres notifications.",
    "Send mode" : "Mode d'envoi",
    "Encryption" : "Chiffrement",
    "Sendmail mode" : "Mode Sendmail",
    "From address" : "Adresse source",
    "Server address" : "Adresse du serveur",
    "Port" : "Port",
    "Authentication method" : "Méthode d'authentification",
    "Only applies when authentication is required" : "Ne s'applique que lorsque l'authentification est requise",
    "Authentication required" : "Authentification requise",
    "Credentials" : "Informations d'identification",
    "SMTP Username" : "Nom d'utilisateur SMTP",
    "SMTP Password" : "Mot de passe SMTP",
    "Save" : "Enregistrer",
    "Test and verify email settings" : "Tester les paramètres de messagerie",
    "Send email" : "Envoyer un e-mail",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Il est important pour la sécurité et la performance de votre instance que celle-ci soit correctement configurée. Afin de vous aider, votre instance Nextcloud effectue des vérifications automatiques. Pour de plus amples informations, veuillez consulter la documentation liée.",
    "All checks passed." : "Tous les tests ont réussi.",
    "There are some errors regarding your setup." : "Il y a quelques erreurs concernant votre configuration.",
    "There are some warnings regarding your setup." : "Il y a quelques avertissements concernant votre configuration.",
    "Checking for system and security issues." : "Vérification des problèmes de système et de sécurité.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Merci de consulter les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guides d'installation ↗</a> et de vérifier les erreurs ou avertissements des <a href=\"%2$s\">logs</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Vérifier la sécurité de votre Nextcloud grâce à <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">notre scan de sécurité ↗</a>",
    "Version" : "Version",
    "You need to enable the File sharing App." : "Vous devez activer l'application de partage de fichiers",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "En tant qu'administrateur, vous pouvez affiner le comportement de partage. Veuillez consulter la documentation pour plus d'informations.",
    "Allow apps to use the Share API" : "Autoriser les applications à utiliser l'API de partage",
    "Set default expiration date for shares" : "Définir une date d'expiration par défaut pour les partages",
    "Expire after" : "Expire après",
    "day(s)" : "jour(s)",
    "Enforce expiration date" : "Imposer la date d'expiration",
    "Set default expiration date for shares to other servers" : "Définir la date d'expiration par défaut pour les partages vers d'autres serveurs",
    "Allow users to share via link and emails" : "Autoriser les utilisateurs à partager par lien et par e-mail",
    "Allow public uploads" : "Autoriser les téléversements publics",
    "Always ask for a password" : "Toujours demander un mot de passe",
    "Enforce password protection" : "Imposer la protection par mot de passe",
    "Exclude groups from password requirements:" : "Exclure des groupes des contraintes de mot de passe :",
    "Set default expiration date" : "Définir une date d'expiration par défaut",
    "Exclude groups from creating link shares:" : "Interdire la création de liens de partage à certains groupes",
    "Allow resharing" : "Autoriser le repartage",
    "Allow sharing with groups" : "Autoriser le partage avec les groupes",
    "Restrict users to only share with users in their groups" : "N'autoriser les partages qu'entre membres de mêmes groupes",
    "Exclude groups from sharing" : "Empêcher certains groupes de partager",
    "These groups will still be able to receive shares, but not to initiate them." : "Ces groupes ne pourront plus initier de partage, mais ils pourront toujours rejoindre les partages faits par d'autres. ",
    "Allow username autocompletion in share dialog" : "Autoriser l'autocomplétion du nom d'utilisateur dans la boite de dialogue de partage",
    "Allow username autocompletion to users within the same groups" : "Autoriser l'autocomplétion du nom d'utilisateur pour les utilisateurs du même groupe",
    "Allow username autocompletion to users based on phone number integration" : "Autoriser l'autocomplétion du nom d'utilisateur aux utilisateurs selon l'intégration du numéro de téléphone",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si les autocomplétions \"même groupe\" et \"intégration du numéro de téléphone\" sont activées, une correspondance avec l'une ou l'autre de ces conditions est suffisante pour afficher l'utilisateur.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Autoriser l'autocomplétion lorsque le nom d'utilisateur ou l'adresse e-mail est totalement saisi⋅e (en ignorant les correspondances manquantes dans le répertoire téléphonique et le fait d'appartenir au même groupe)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Afficher les conditions d'utilisation sur la page publique de téléversement (seulement lorsque la liste des fichiers est masquée).",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ce texte sera affiché sur la page publique de téléversement lorsque la liste des fichiers est masquée.",
    "Default share permissions" : "Autorisations de partage par défaut",
    "Reasons to use Nextcloud in your organization" : "Raisons d'utiliser Nextcloud dans votre organisation",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Développé par la {communityopen}communauté Nextcloud{linkclose}, le {githubopen}code source{linkclose} est sous licence {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Aimez notre page Facebook",
    "Follow us on Twitter" : "Suivez-nous sur Twitter",
    "Follow us on Mastodon" : "Suivez-nous sur Mastodon",
    "Check out our blog" : "Découvrez notre blog",
    "Subscribe to our newsletter" : "Abonnez-vous à notre lettre d'information",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Cette version communautaire de Nextcloud n'est pas supportée et les notifications push ne sont pas disponibles.",
    "Use a second factor besides your password to increase security for your account." : "Utilisez un second facteur d'authentification en plus de votre mot de passe pour renforcer la sécurité de votre compte.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si vous utilisez des applications tierces pour vous connecter à Nextcloud, assurez-vous de créer et de configurer un mot de passe d'application pour chacune avant d'activer l'authentification à deux facteurs.",
    "An error occurred while changing your language. Please reload the page and try again." : "Une erreur est survenue lors du changement de votre langue. Veuillez recharger la page et réessayer.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Une erreur est survenue lors du changement de vos paramètres régionaux. Veuillez recharger la page et réessayer.",
    "Select a profile picture" : "Selectionnez une photo de profil ",
    "Week starts on {fdow}" : "La semaine commence le {fdow}",
    "You created app password \"{token}\"" : "Vous avez créé un mot de passe d'application \"{token}\"",
    "An administrator created app password \"{token}\"" : "Un administrateur a créé un mot de passe d'application \"{token}\"",
    "Couldn't remove app." : "Impossible de supprimer l'application.",
    "Couldn't update app." : "Impossible de mettre à jour l'application",
    "Backend doesn't support password change, but the user's encryption key was updated." : "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement de l'utilisateur a été mise à jour.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Impossible de déterminer si la version TLS de cURL est dépassée ou non en raison d’une erreur survenue lors de la requête HTTPS vers https://nextcloud.com. Veuillez consulter le fichier de log de nextcloud pour plus de détails.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Le nombre maximum de clés OPcache est presque dépassé. Pour vous assurer que tous les scripts puissent être conservés en cache, il est recommandé de définir la variable <code>opcache.max_accelerated_files</code> de votre fichier de configuration PHP à une valeur supérieure à<code>%s</code>.",
    "Admin privileges" : "Privilèges d'administrateur",
    "Unable to update biography" : "Impossible de mettre à jour la biographie",
    "Unable to update full name" : "Impossible de mettre à jour le nom complet",
    "No full name set" : "Aucun nom complet configuré",
    "Unable to update headline" : "Impossible de mettre à jour le titre",
    "Unable to update organisation" : "Impossible de mettre à jour l'organisation",
    "Unable to update role" : "Impossible de modifier la fonction",
    "Change scope level of {accountProperty}" : "Changer le niveau de confidentialité de {accountProperty}",
    "Unable to update federation scope of the primary {accountProperty}" : "Impossible de mettre à jour la confidentialité de fédération du {accountProperty} primaire",
    "Unable to update federation scope of additional {accountProperty}" : "Impossible de mettre à jour la confidentialité de fédération du {accountProperty} supplémentaire",
    "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
    "Migration started …" : "Migration démarrée...",
    "Address" : "Adresse",
    "Avatar" : "Avatar",
    "An error occured during the request. Unable to proceed." : "Une erreur est survenue durant la requête. Impossible de traiter la demande.",
    "Plain" : "En clair",
    "NT LAN Manager" : "Gestionnaire du réseau NT",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "Veuillez lire ceci avec attention avant d'activer le chiffrement :",
    "Enable encryption" : "Activer le chiffrement",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle. Veuillez activer l'application \"Default Encryption Module\" et exécuter 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Vous devez migrer vos clés de chiffrement de l'ancienne (ownCloud <= 8.0) vers la nouvelle.",
    "Start migration" : "Démarrer la migration",
    "Last job execution ran %s. Something seems wrong." : "Quelque chose s'est mal passé lors de l'exécution de la dernière tâche %s.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Certaines tâches n'ont pas été exécutées depuis %s. Vous pourriez augmenter la fréquence d'exécution.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Certaines tâches n’ont pas été exécutées depuis %s. Veuillez envisager de passer à un système de cron.",
    "Last job ran %s." : "Dernière tâche exécutée %s.",
    "Background job didn’t run yet!" : "La tâche de fond n'a pas encore été exécutée !",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Pour que le serveur fonctionne correctement, il est important de configurer correctement les tâches d'arrière-plan. \"Cron\" est le règlage recommandé. Veuillez vous référer à la documentation Nextcloud pour plus d'informations.",
    "Pick background job setting" : "Définir les paramètres pour la tâche d'arrière-plan",
    "Recommended" : "Recommandé",
    "The cron.php needs to be executed by the system user \"%s\"." : "Le cron.php doit être exécuté par l'utilisateur système \"%s\".",
    "Change privacy level of profile picture" : "Changer le niveau de confidentialité de la photo de profil",
    "Upload new" : "Téléverser une nouvelle image",
    "Select from Files" : "Sélectionner depuis Fichiers",
    "Remove image" : "Supprimer la photo",
    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 Mo",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Veuillez noter que cela peut prendre jusqu'à 24 heures pour que l'avatar soit mis à jour partout.",
    "Choose as profile picture" : "Définir comme image de profil",
    "You are using <strong>%s</strong>" : "Vous utilisez <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Vous utilisez <strong>%1$s</strong> sur <strong>%2$s</strong> (<strong>%3$s%% </strong>)",
    "Change privacy level of phone number" : "Changer le niveau de confidentialité du numéro de téléphone",
    "Change privacy level of address" : "Changer le niveau de confidentialité de l'adresse",
    "Your postal address" : "Votre adresse postale",
    "Change privacy level of website" : "Changer le niveau de confidentialité du site web",
    "It can take up to 24 hours before the account is displayed as verified." : "Cela peut prendre jusqu'à 24 heures avant que le compte soit affiché comme vérifié.",
    "Link https://…" : "Lien https://…",
    "Change privacy level of Twitter profile" : "Changer le niveau de confidentialité du profil Twitter",
    "Twitter handle @…" : "Pseudo Twitter @...",
    "Choose profile picture from files" : "Choisir une image parmi les fichiers"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
